diff --git a/needles/anaconda_install_root_password_screen_olddpi.json b/needles/anaconda_install_root_password_screen_olddpi.json
new file mode 100644
--- /dev/null
+++ b/needles/anaconda_install_root_password_screen_olddpi.json
@@ -0,0 +1,18 @@
+{
+    "area": [
+        {
+            "height": 16,
+            "type": "match",
+            "width": 96,
+            "xpos": 241,
+            "ypos": 111
+        }
+    ],
+    "properties": [],
+    "tags": [
+        "anaconda_install_root_password_screen",
+        "ENV-DISTRI-fedora",
+        "ENV-LANGUAGE-ENGLISH",
+        "ENV-FLAVOR-server"
+    ]
+}
\ No newline at end of file
diff --git a/needles/anaconda_install_root_password_screen_olddpi.png b/needles/anaconda_install_root_password_screen_olddpi.png
new file mode 100644
index 0000000000000000000000000000000000000000..0000000000000000000000000000000000000000
GIT binary patch
diff --git a/needles/anaconda_install_user_creation_screen_olddpi.json b/needles/anaconda_install_user_creation_screen_olddpi.json
new file mode 100644
--- /dev/null
+++ b/needles/anaconda_install_user_creation_screen_olddpi.json
@@ -0,0 +1,25 @@
+{
+    "area": [
+        {
+            "height": 17,
+            "type": "match",
+            "width": 69,
+            "xpos": 269,
+            "ypos": 136
+        },
+        {
+            "height": 17,
+            "type": "match",
+            "width": 62,
+            "xpos": 277,
+            "ypos": 269
+        }
+    ],
+    "properties": [],
+    "tags": [
+        "anaconda_install_user_creation_screen",
+        "ENV-DISTRI-fedora",
+        "ENV-LANGUAGE-ENGLISH",
+        "ENV-FLAVOR-server"
+    ]
+}
\ No newline at end of file
diff --git a/needles/anaconda_install_user_creation_screen_olddpi.png b/needles/anaconda_install_user_creation_screen_olddpi.png
new file mode 100644
index 0000000000000000000000000000000000000000..0000000000000000000000000000000000000000
GIT binary patch
diff --git a/needles/anaconda_main_hub_live.json b/needles/anaconda_main_hub_live.json
--- a/needles/anaconda_main_hub_live.json
+++ b/needles/anaconda_main_hub_live.json
@@ -3,7 +3,7 @@
     "anaconda_main_hub",
     "ENV-DISTRI-fedora",
     "ENV-LANGUAGE-ALL",
-    "ENV-INSTALLER-live"
+    "INSTALLER-smallhub"
   ],
   "area": [
     {
diff --git a/needles/anaconda_select_install_lang_english_filtered.json b/needles/anaconda_select_install_lang_english_filtered.json
--- a/needles/anaconda_select_install_lang_english_filtered.json
+++ b/needles/anaconda_select_install_lang_english_filtered.json
@@ -1,24 +1,24 @@
-{
-  "area": [
-    {
-      "width": 103,
-      "xpos": 207,
-      "height": 45,
-      "type": "match",
-      "ypos": 196
-    },
-    {
-      "width": 79,
-      "height": 54,
-      "type": "match",
-      "xpos": 483,
-      "ypos": 195
-    }
-  ],
-  "tags": [
-    "anaconda_select_install_lang_filtered",
-    "ENV-DESKTOP-default",
-    "ENV-DISTRI-fedora",
-    "ENV-LANGUAGE-ENGLISH"
-  ]
-}
+{
+    "area": [
+        {
+            "height": 25,
+            "type": "match",
+            "width": 58,
+            "xpos": 222,
+            "ypos": 206
+        },
+        {
+            "height": 21,
+            "type": "match",
+            "width": 66,
+            "xpos": 490,
+            "ypos": 210
+        }
+    ],
+    "tags": [
+        "anaconda_select_install_lang_filtered",
+        "ENV-DESKTOP-default",
+        "ENV-DISTRI-fedora",
+        "ENV-LANGUAGE-ENGLISH"
+    ]
+}
\ No newline at end of file
diff --git a/needles/anaconda_spoke_done_olddpi.json b/needles/anaconda_spoke_done_olddpi.json
new file mode 100644
--- /dev/null
+++ b/needles/anaconda_spoke_done_olddpi.json
@@ -0,0 +1,17 @@
+{
+    "area": [
+        {
+            "height": 22,
+            "type": "match",
+            "width": 55,
+            "xpos": 23,
+            "ypos": 38
+        }
+    ],
+    "tags": [
+        "anaconda_spoke_done",
+        "ENV-DESKTOP-default",
+        "ENV-DISTRI-fedora",
+        "ENV-LANGUAGE-ENGLISH"
+    ]
+}
\ No newline at end of file
diff --git a/needles/anaconda_spoke_done_olddpi.png b/needles/anaconda_spoke_done_olddpi.png
new file mode 100644
index 0000000000000000000000000000000000000000..0000000000000000000000000000000000000000
GIT binary patch
diff --git a/templates b/templates
--- a/templates
+++ b/templates
@@ -81,6 +81,16 @@
                       product    => {
                                       arch    => "x86_64",
                                       distri  => "fedora",
+                                      flavor  => "cloud_atomic_canned",
+                                      version => "*",
+                                    },
+                      test_suite => { name => "default_install" },
+                    },
+                    {
+                      machine    => { name => "64bit" },
+                      product    => {
+                                      arch    => "x86_64",
+                                      distri  => "fedora",
                                       flavor  => "universal",
                                       version => "*",
                                     },
@@ -627,6 +637,17 @@
                     {
                       arch      => "x86_64",
                       distri    => "fedora",
+                      flavor    => "cloud_atomic_canned",
+                      name      => "",
+                      settings  => [
+                        { key => "CANNED", value => "1" }
+                                   ],
+                      variables => "",
+                      version   => "*",
+                    },
+                    {
+                      arch      => "x86_64",
+                      distri    => "fedora",
                       flavor    => "workstation_live",
                       name      => "",
                       settings  => [


diff --git a/main.pm b/main.pm
--- a/main.pm
+++ b/main.pm
@@ -45,14 +45,15 @@
 }
 
 sub cleanup_needles() {
-    if (!get_var('LIVE')) {
-        ## Unregister live-only installer needles. The main issue is the
-        ## hub: on non-live we want to wait for repository setup to complete,
-        ## but if we match that spoke's "ready" icon, it breaks live because
-        ## it doesn't have that spoke. So we have a live needle which doesn't
-        ## match on that icon, but we unregister it for non-live installs so
-        ## they don't match on it too soon.
-        unregister_needle_tags("ENV-INSTALLER-live");
+    if (!get_var('LIVE') and !get_var('CANNED')) {
+        ## Unregister smaller hub needles. Live and 'canned' installers have
+        ## a smaller hub with no repository spokes. On other images we want
+        ## to wait for repository setup to complete, but if we match that
+        ## spoke's "ready" icon, it breaks live and canned because they
+        ## don't have that spoke. So we have a needle which doesn't match
+        ## on that icon, but we unregister it for other installs so they
+        ## don't match on it too soon.
+        unregister_needle_tags("INSTALLER-smallhub");
     }
 
     # Unregister non-language-appropriate needles. Needles which are expected